@@ -9,10 +9,8 @@ import matplotlib.pyplot as plt
 
 class FlatField:
     '''
-    FlatField (using Python 3) computes a flatfield image in aXe definition.
-    This can easily be implemented following the use of ComputeTraceNWavelength.
-    Given obj = ComputeTraceNWavelength(...), and obj.compute() is called,
-        a user can start with flat = FlatField(flatfile,obj.wavelength['WW'])
+    FlatField (using python 3) computes a flatfield image in aXe definition.
+    This requires flatfile produced for aXe, and tracefile produced by hstgrism package.
     flat.flatfile to see the path to flatfile.
     flat.data to see inputs for the computation.
     flat.compute() to compute the flatfield image.
@@ -51,16 +49,18 @@ class FlatField:
         self.data['FLAT'] = copy.deepcopy(tmpp)
         # wavelength
         tmp = pd.read_csv(self.tracefile)
-        dydx = tmp['DYDX']
-        m = np.isfinite(dydx)
-        dydx = dydx[m].values
+        dldp = tmp['DLDP']
+        m = np.isfinite(dldp)
+        dldp = dldp[m].values
         xg = np.arange(self.data['NAX1'])
         xref = tmp['XREF'][0]
         xh = xg-xref
         ww = np.full_like(xh,0.,dtype=float)
-        for i,ii in enumerate(dydx):
+        for i,ii in enumerate(dldp):
             ww += ii * np.power(xh,i)
         self.data['WW'] = ww
+        self.data['XG'] = xg
+        self.data['XREF'] = xref
     ##########
     ##########
     ##########
@@ -83,7 +83,7 @@ class FlatField:
     ##########
     ##########
     ##########
-    def save(self,savename_prefix='image',overwrite=False):
+    def save(self,savename_prefix=None,overwrite=True):
         hdu = fits.PrimaryHDU()
         hdul = fits.HDUList([hdu])
         hdul[0].header['NAXIS'] = 2
@@ -95,6 +95,8 @@ class FlatField:
         hdul[0].header['TRACE'] = self.tracefile
         hdul[0].header['ROOTNAME'] = self.data['ROOTNAME']
         hdul[0].data = self.flatfield.copy()
+        if savename_prefix is None:
+            savename_prefix = self.data['ROOTNAME']
         string = '{0}_flat.fits'.format(savename_prefix)
         hdul.writeto(string,overwrite=overwrite)
         print('Save {0}'.format(string))
@@ -102,7 +104,7 @@ class FlatField:
     ##########
     ##########
     def show(self,
-             save=False,savename_prefix='image',saveformat='eps',
+             save=False,savename_prefix=None,saveformat='pdf',
              params={'figsize':(5,5),
                      'minmax':(5.,99.),
                      'cmap':'viridis',
@@ -120,6 +122,8 @@ class FlatField:
         plt.title(self.data['ROOTNAME'],fontsize=fontsize)
         plt.tight_layout()
         if save:
+            if savename_prefix is None:
+                savename_prefix = self.data['ROOTNAME']
             string = '{0}_flat.{1}'.format(savename_prefix,saveformat)
             plt.savefig(string,format=saveformat,bbox_inches='tight')
             print('Save {0}'.format(string))
